import { labeledXAxis, labeledYAxis } from './labeledAxes';
import { theme } from './theme';

render();
window.addEventListener('resize', render);

function render() {
  const body = d3.select('body');
  myResponsiveComponent(body, Object.assign({}, theme, {
    width: document.body.clientWidth,
    height: document.body.clientHeight,
    margin: { top: 20, bottom: 71, left: 78, right: 20 },
    xAxisLabel: 'X Axis',
    yAxisLabel: 'Y Axis'
  }));
}

function myResponsiveComponent(selection, props) {
  const { width, height, margin } = props;

  let svg = selection.selectAll('svg').data([null]);
  svg = svg.enter().append('svg')
    .merge(svg)
      .attr('width', width)
      .attr('height', height);

  const { g, innerWidth, innerHeight } = marginConvention(svg, { width, height, margin });

  const rect = g.selectAll('rect').data([null]);
  rect
    .enter().append('rect')
      .attr('rx', 100)
    .merge(rect)
      .attr('width', innerWidth)
      .attr('height', innerHeight);

  const yScale = d3.scaleLinear()
    .domain([0, 1])
    .range([innerHeight, 0]);

  labeledYAxis(g, Object.assign({}, props, {
    yScale,
    innerHeight
  }));

  const xScale = d3.scaleLinear()
    .domain([0, 1])
    .range([0, innerWidth]);

  labeledXAxis(g, Object.assign({}, props, {
    xScale,
    innerWidth,
    innerHeight
  }));
}